@@ -11,6 +11,7 @@ from pyxllib.algo.pupil import make_index_function
 from pyxllib.prog.newbie import round_int
 from pyxllib.prog.pupil import DictTool
 from pyxllib.gui.qt import WaitMessageBox
+from xlproject.xlserverlib import XlServer
 
 from xllabelme import utils
 
@@ -99,7 +100,8 @@ class XlLabel:
         self.reset()
         # self.config_label_menu()  # 配置界面
 
-        self.ppocr = None
+        # TODO 晚点这个要配置化，防止被大量盗用~~
+        self.xlserver = XlServer('118.195.202.82', token='xllabelmey^*A9ykj')
 
     def reset(self, mode=None):
         # 1 确定mode
@@ -164,7 +166,7 @@ class XlLabel:
         label = self.cfg.get('default_label', '')
         if self.auto_rec_text and shape:
             k = 'label' if 'label' in self.keys else 'text'
-            text, score = self.rec_text(self.mainwin.imagePath, shape.points)
+            text, score = self.rec_text(shape.points)
             label = self.set_label_attr(label, k, text)
             label = self.set_label_attr(label, 'score', score)
         return label
@@ -217,8 +219,6 @@ class XlLabel:
 
             def func(x):
                 self.auto_rec_text = x
-                if x:
-                    self.ensure_ppocr()
 
             a.triggered.connect(func)
             return a
@@ -361,7 +361,7 @@ class XlLabel:
                 x = self.set_label_attr(x, 'text', text)
         else:  # Shape结构
             if text is None:
-                if self.ppocr:
+                if self.auto_rec_text:
                     labelattr = self.get_labelattr(x.label)
                     labelattr['text'], labelattr['score'] = self.rec_text(x.points)
                     x.label = self.json_dumps(labelattr)
@@ -373,20 +373,14 @@ class XlLabel:
     def __smart_label(self):
         """ 智能标注相关 """
 
-    def ensure_ppocr(self):
-        if not hasattr(self, 'ppocr'):
-            with WaitMessageBox(self.mainwin, 'PaddleOCR模型初始化中，请稍等一会...'):
-                from pyxlpr.paddleocr import PaddleOCR
-                self.ppocr = PaddleOCR.build_ppocr()
-
     def rec_text(self, points):
-        from pyxllib.xlcv import xlcv
+        from pyxllib.cv.xlcvlib import xlcv
         # 识别指定的points区域
-        if isinstance(points, QPointF):
+        if isinstance(points[0], QPointF):
             points = [(p.x(), p.y()) for p in points]
         im = xlcv.get_sub(self.mainwin.arr_image, points, warp_quad=True)
-        text, score = self.ppocr.rec_singleline(im)
-        return text, score
+        text = self.xlserver.rec_singleline(im)
+        return text, -1
 
     def __right_click_shape(self):
         """ 扩展shape右键操作菜单功能
